@@ -18,7 +18,7 @@
 // along with this program ; if not, write to the Free Software
 // Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 //
-// $Id: OwnershipManagement.cc,v 3.16 2008/06/12 07:39:50 erk Exp $
+// $Id: OwnershipManagement.cc,v 3.19 2009/10/11 11:13:15 erk Exp $
 // ----------------------------------------------------------------------------
 
 #include <config.h>
@@ -74,9 +74,7 @@ OwnershipManagement::attributeOwnedByFederate(ObjectHandle theObject,
     req.federation = fm->_numero_federation ;
     req.federate = fm->federate ;
     req.object = theObject ;
-    req.handleArray.resize(1) ;
-    req.handleArray[0] = theAttribute ;
-    req.handleArraySize = 1 ;
+    req.setAttribute(theAttribute);
 
     D.Out(pdDebug, "Federate %u ", fm->federate);
 
@@ -87,7 +85,7 @@ OwnershipManagement::attributeOwnedByFederate(ObjectHandle theObject,
                       NetworkMessage::IS_ATTRIBUTE_OWNED_BY_FEDERATE,
                       req.federate));
 
-    e = rep->exception ;
+    e = rep->getException() ;
 
     if (e == e_NO_EXCEPTION)
         return(rep->getLabel().c_str());
@@ -122,7 +120,7 @@ OwnershipManagement::queryAttributeOwnership(ObjectHandle theObject,
     //AttendreMsg ne sert que pour verifier que la transmission a ete OK
     std::auto_ptr<NetworkMessage> rep(comm->waitMessage(NetworkMessage::QUERY_ATTRIBUTE_OWNERSHIP, req.federate));
 
-    e = rep->exception ;
+    e = rep->getException() ;
 }
 
 // ----------------------------------------------------------------------------
@@ -156,7 +154,7 @@ negotiatedAttributeOwnershipDivestiture(ObjectHandle theObject,
     std::auto_ptr<NetworkMessage> rep(comm->waitMessage(NetworkMessage::NEGOTIATED_ATTRIBUTE_OWNERSHIP_DIVESTITURE,
                       req.federate));
 
-    e = rep->exception ;
+    e = rep->getException() ;
 }
 
 // ----------------------------------------------------------------------------
@@ -188,7 +186,7 @@ cancelnegotiatedAttributeOwnershipDivestiture(ObjectHandle theObject,
                       NetworkMessage::CANCEL_NEGOTIATED_ATTRIBUTE_OWNERSHIP_DIVESTITURE,
                       req.federate));
 
-    e = rep->exception ;
+    e = rep->getException() ;
 }
 
 // ----------------------------------------------------------------------------
@@ -218,7 +216,7 @@ attributeOwnershipAcquisitionIfAvailable(ObjectHandle theObject,
     std::auto_ptr<NetworkMessage> rep(comm->waitMessage(NetworkMessage::ATTRIBUTE_OWNERSHIP_ACQUISITION_IF_AVAILABLE,
                       req.federate));
 
-    e = rep->exception ;
+    e = rep->getException() ;
 }
 
 // ----------------------------------------------------------------------------
@@ -249,7 +247,7 @@ unconditionalAttributeOwnershipDivestiture(ObjectHandle theObject,
     std::auto_ptr<NetworkMessage> rep(comm->waitMessage(NetworkMessage::UNCONDITIONAL_ATTRIBUTE_OWNERSHIP_DIVESTITURE,
                       req.federate));
 
-    e = rep->exception ;
+    e = rep->getException() ;
 }
 
 // ----------------------------------------------------------------------------
@@ -282,7 +280,7 @@ attributeOwnershipAcquisition(ObjectHandle theObject,
     std::auto_ptr<NetworkMessage> rep(comm->waitMessage(NetworkMessage::ATTRIBUTE_OWNERSHIP_ACQUISITION,
                       req.federate));
 
-    e = rep->exception ;
+    e = rep->getException() ;
 }
 
 // ----------------------------------------------------------------------------
@@ -315,11 +313,11 @@ attributeOwnershipRealeaseResponse(ObjectHandle theObject,
     std::auto_ptr<NetworkMessage> rep(comm->waitMessage(NetworkMessage::ATTRIBUTE_OWNERSHIP_RELEASE_RESPONSE,
                       req.federate));
 
-    e = rep->exception ;
+    e = rep->getException() ;
 
     if (e == e_NO_EXCEPTION) {
         AttributeHandleSet *AttributeSet ;
-        AttributeSet = RTI::AttributeHandleSetFactory::create(rep->handleArraySize);
+        AttributeSet = new AttributeHandleSet(rep->handleArraySize);
 
         for (int i = 0 ; i < rep->handleArraySize ; i++) {
             AttributeSet->add(rep->handleArray[i]);
@@ -358,7 +356,7 @@ cancelattributeOwnershipAcquisition(ObjectHandle theObject,
     std::auto_ptr<NetworkMessage> rep(comm->waitMessage(NetworkMessage::CANCEL_ATTRIBUTE_OWNERSHIP_ACQUISITION,
                       req.federate));
 
-    e = rep->exception ;
+    e = rep->getException() ;
 }
 
 // ----------------------------------------------------------------------------
@@ -514,4 +512,4 @@ confirmAttributeOwnershipAcquisitionCancellation(ObjectHandle the_object,
 
 }} // namespace certi/rtia
 
-// $Id: OwnershipManagement.cc,v 3.16 2008/06/12 07:39:50 erk Exp $
+// $Id: OwnershipManagement.cc,v 3.19 2009/10/11 11:13:15 erk Exp $
